#!/usr/bin/env python 
import rospy
from radar_sensor_plugin.msg import radar_data
import numpy as np
import matplotlib.mlab as mlab
import matplotlib.pyplot as plt
import matplotlib.animation as Animation
from matplotlib import style
from numpy import convolve
import matplotlib

style.use('fivethirtyeight')

INTERVAL = 5 # seconds to sleep between data update calls

#global variables to hold the data
xdata = []
ydata = []

def callback(data):
    global xdata, ydata
    xdata = data.range
    ydata = data.histogram_bar

def animate(i):
    global ydata, xdata

    # update the data
    line.set_data(xdata, ydata)

    # update the scales to fit:
    if ydata:
        ax.set_ylim(min(ydata), max(ydata))
    if xdata:
        ax.set_xlim(min(xdata), max(xdata))

    return line
    
def listener():

    # In ROS, nodes are uniquely named. If two nodes with the same
    # node are launched, the previous one is kicked off. The
    # anonymous=True flag means that rospy will choose a unique
    # name for our 'listener' node so that multiple listeners can
    # run simultaneously.

    rospy.init_node('plotter', anonymous=True)

    rospy.Subscriber("radar1", radar_data, callback)
    
    global ax, line
    fig = plt.figure()
    ax = fig.add_subplot(111)
    ax.set_xlabel('Range')
    ax.set_ylabel('Amplitude')
    line, = ax.plot([], [], lw=2) # initial empty graph
    ani = Animation.FuncAnimation(fig, animate, interval=200)
    plt.show() # start animation loop


    # spin() simply keeps python from exiting until this node is stopped
    rospy.spin()
    
if __name__ == '__main__':
    listener()
