#!/usr/bin/env python 
import rospy
from radar_sensor_plugin.msg import radar_data
import numpy as np
import matplotlib.mlab as mlab
import matplotlib.pyplot as plt
import matplotlib.animation as Animation
import matplotlib.cm as cm
from matplotlib import style
from scipy.interpolate import interp1d
import matplotlib

style.use('fivethirtyeight')

# Global variables to hold the data
xdata = []
ydata = []

quadrotor_position = 0
interp_x = interp1d([-3.2, 0.0], [0, 29])
interp_y = interp1d([0, 10], [0, 99])
image = np.zeros((100, 30))
image[0][0] = 0.4

def callback(data):
    global xdata, ydata, quadrotor_position
    xdata = data.range
    ydata = data.histogram_bar
    quadrotor_position = data.position

def animate(i):
    global xdata, ydata
    im.set_array(update_grid(xdata, ydata))
    return im,
    
def update_grid(ranges, amplitudes):
    global interp_x, interp_y, initialized, image

    if ydata:
        x_value = quadrotor_position[0]
        if (x_value < -3.2):
            x_value = -3.2
        if x_value > 0.0:
            x_value = 0.0
        x_value = round(interp_x(x_value), 0)
        for i in range(len(ranges)):
            y_value = round(interp_y(ranges[i]), 0)
            image[99-y_value][x_value] = amplitudes[i]
      
    return image
    
def listener():

    # In ROS, nodes are uniquely named. If two nodes with the same
    # node are launched, the previous one is kicked off. The
    # anonymous=True flag means that rospy will choose a unique
    # name for our 'listener' node so that multiple listeners can
    # run simultaneously.

    rospy.init_node('plotter', anonymous=True)

    rospy.Subscriber("radar1", radar_data, callback)
    
    global im
    fig = plt.figure()

    im = plt.imshow(update_grid(xdata, ydata), animated=True, cmap="hot", extent=[-3.2,0.5,0,10])

    ani = Animation.FuncAnimation(fig, animate, interval=200)
    plt.show() # start animation loop

    # spin() simply keeps python from exiting until this node is stopped
    rospy.spin()
    
if __name__ == '__main__':
    listener()
